EraVM opcodes.
Structs
- Add
Addopcode.- And
Andopcode.- AuxHeap
Read AuxHeapReadopcode.- AuxHeap
Write AuxHeapWriteopcode.- AuxMutating0
AuxMutating0opcode.- Caller
Calleropcode.- Code
Address CodeAddressopcode.- Context
Meta ContextMetaopcode.- Context
U128 ContextU128opcode.- Decommit
Decommitopcode.- Delegate
- Delegate
FarCallmode. - Div
Divopcode.- Ergs
Left ErgsLeftopcode.- Event
Eventopcode.- FarCall
FarCallgroup of opcodes distinguished by the calling mode (normal, delegate, or mimic).- Heap
Read HeapReadopcode.- Heap
Write HeapWriteopcode.- Increment
TxNumber IncrementTxNumberopcode.- Jump
Jumpopcode.- L2To
L1Message L2ToL1Messageopcode.- Mimic
- Mimic
FarCallmode. - Mul
Mulopcode.- Near
Call NearCallopcode.- Nop
Nopopcode.- Normal
- Normal
Return mode /FarCallmode. - Or
Oropcode.- Panic
- Panic
Return mode. - Pointer
Add PointerAddopcode.- Pointer
Pack PointerPackopcode.- Pointer
Read PointerReadopcode.- Pointer
Shrink PointerShrinkopcode.- Pointer
Sub PointerSubopcode.- Precompile
Call PrecompileCallopcode.- Ret
Retgroup of opcodes distinguished by the return type (normal, panic, or revert).- Revert
- Revert
Return mode. - Rotate
Left RotateLeftopcode.- Rotate
Right RotateRightopcode.- SP
SPopcode.- SetContext
U128 SetContextU128opcode.- Shift
Left ShiftLeftopcode.- Shift
Right ShiftRightopcode.- Storage
Read StorageReadopcode.- Storage
Write StorageWriteopcode.- Sub
Subopcode.- This
Thisopcode.- Transient
Storage Read TransientStorageReadopcode.- Transient
Storage Write TransientStorageWriteopcode.- Xor
Xoropcode.
Traits
- Type
Level Calling Mode - Calling mode for the
FarCallopcodes. - Type
Level Return Type - Return type for the
Retopcodes.